@@ -2,10 +2,10 @@
 //! a better name for the file.  Since I called data collection "harvesting",
 //! then this is the farmer I guess.
 //!
-//! Essentially the main goal is to shift the initial calculation and distribution
-//! of joiner points and data to one central location that will only do it
-//! *once* upon receiving the data --- as opposed to doing it on canvas draw,
-//! which will be a costly process.
+//! Essentially the main goal is to shift the initial calculation and
+//! distribution of joiner points and data to one central location that will
+//! only do it *once* upon receiving the data --- as opposed to doing it on
+//! canvas draw, which will be a costly process.
 //!
 //! This will also handle the *cleaning* of stale data.  That should be done
 //! in some manner (timer on another thread, some loop) that will occasionally
@@ -18,11 +18,14 @@ use std::{collections::BTreeMap, time::Instant, vec::Vec};
 use hashbrown::HashMap;
 
 #[cfg(feature = "battery")]
-use crate::data_harvester::batteries;
+use crate::data_collection::batteries;
 use crate::{
-    data_harvester::{cpu, disks, memory, network, processes::ProcessHarvest, temperature, Data},
-    utils::gen_util::{get_decimal_bytes, GIGA_LIMIT},
-    Pid,
+    data_collection::{
+        cpu, disks, memory, network,
+        processes::{Pid, ProcessHarvest},
+        temperature, Data,
+    },
+    utils::data_prefixes::*,
 };
 
 pub type TimeOffset = f64;
@@ -99,8 +102,8 @@ impl ProcessData {
 /// collected, and what is needed to convert into a displayable form.
 ///
 /// If the app is *frozen* - that is, we do not want to *display* any changing
-/// data, keep updating this. As of 2021-09-08, we just clone the current collection
-/// when it freezes to have a snapshot floating around.
+/// data, keep updating this. As of 2021-09-08, we just clone the current
+/// collection when it freezes to have a snapshot floating around.
 ///
 /// Note that with this method, the *app* thread is responsible for cleaning -
 /// not the data collector.
@@ -318,7 +321,7 @@ impl DataCollection {
         cpu.iter()
             .for_each(|cpu| new_entry.cpu_data.push(cpu.cpu_usage));
 
-        self.cpu_harvest = cpu.to_vec();
+        self.cpu_harvest = cpu;
     }
 
     fn eat_load_avg(&mut self, load_avg: cpu::LoadAvgHarvest, new_entry: &mut TimedData) {
@@ -328,27 +331,38 @@ impl DataCollection {
     }
 
     fn eat_temp(&mut self, temperature_sensors: Vec<temperature::TempHarvest>) {
-        // TODO: [PO] To implement
-        self.temp_harvest = temperature_sensors.to_vec();
+        self.temp_harvest = temperature_sensors;
     }
 
     fn eat_disks(
         &mut self, disks: Vec<disks::DiskHarvest>, io: disks::IoHarvest, harvested_time: Instant,
     ) {
-        // TODO: [PO] To implement
         let time_since_last_harvest = harvested_time
             .duration_since(self.current_instant)
             .as_secs_f64();
 
         for (itx, device) in disks.iter().enumerate() {
             let checked_name = {
-                cfg_if::cfg_if! {
-                    if #[cfg(target_os = "windows")] {
-                        match &device.volume_name {
-                            Some(volume_name) => Some(volume_name.as_str()),
-                            None => device.name.split('/').last(),
+                #[cfg(target_os = "windows")]
+                {
+                    match &device.volume_name {
+                        Some(volume_name) => Some(volume_name.as_str()),
+                        None => device.name.split('/').last(),
+                    }
+                }
+                #[cfg(not(target_os = "windows"))]
+                {
+                    #[cfg(feature = "zfs")]
+                    {
+                        if !device.name.starts_with('/') {
+                            Some(device.name.as_str()) // use the whole zfs
+                                                       // dataset name
+                        } else {
+                            device.name.split('/').last()
                         }
-                    } else {
+                    }
+                    #[cfg(not(feature = "zfs"))]
+                    {
                         device.name.split('/').last()
                     }
                 }
@@ -356,23 +370,27 @@ impl DataCollection {
 
             if let Some(checked_name) = checked_name {
                 let io_device = {
-                    cfg_if::cfg_if! {
-                        if #[cfg(target_os = "macos")] {
-                            use once_cell::sync::Lazy;
-                            use regex::Regex;
+                    #[cfg(target_os = "macos")]
+                    {
+                        use std::sync::OnceLock;
 
-                            // Must trim one level further for macOS!
-                            static DISK_REGEX: Lazy<Regex> =
-                                Lazy::new(|| Regex::new(r"disk\d+").unwrap());
-                            if let Some(new_name) = DISK_REGEX.find(checked_name) {
-                                io.get(new_name.as_str())
-                            } else {
-                                None
-                            }
+                        use regex::Regex;
+
+                        // Must trim one level further for macOS!
+                        static DISK_REGEX: OnceLock<Regex> = OnceLock::new();
+                        if let Some(new_name) = DISK_REGEX
+                            .get_or_init(|| Regex::new(r"disk\d+").unwrap())
+                            .find(checked_name)
+                        {
+                            io.get(new_name.as_str())
                         } else {
-                            io.get(checked_name)
+                            None
                         }
                     }
+                    #[cfg(not(target_os = "macos"))]
+                    {
+                        io.get(checked_name)
+                    }
                 };
 
                 if let Some(io_device) = io_device {
@@ -457,6 +475,6 @@ impl DataCollection {
         gpu.iter().for_each(|data| {
             new_entry.gpu_data.push(data.1.use_percent);
         });
-        self.gpu_harvest = gpu.to_vec();
+        self.gpu_harvest = gpu;
     }
 }
