@@ -2,12 +2,12 @@ use std::{ops::Range, time::Instant};
 
 use hashbrown::HashMap;
 use indexmap::IndexMap;
+use unicode_ellipsis::grapheme_width;
 use unicode_segmentation::{GraphemeCursor, GraphemeIncomplete, UnicodeSegmentation};
 
 use crate::{
     app::{layout_manager::BottomWidgetType, query::*},
     constants,
-    utils::gen_util::str_width,
     widgets::{
         BatteryWidgetState, CpuWidgetState, DiskTableWidget, MemWidgetState, NetWidgetState,
         ProcWidgetState, TempWidgetState,
@@ -112,7 +112,8 @@ impl Default for AppSearchState {
 }
 
 impl AppSearchState {
-    /// Resets the [`AppSearchState`] to its default state, albeit still enabled.
+    /// Resets the [`AppSearchState`] to its default state, albeit still
+    /// enabled.
     pub fn reset(&mut self) {
         *self = AppSearchState {
             is_enabled: self.is_enabled,
@@ -161,7 +162,8 @@ impl AppSearchState {
                         // Use the current index.
                         start_index
                     } else if cursor_range.end >= available_width {
-                        // If the current position is past the last visible element, skip until we see it.
+                        // If the current position is past the last visible element, skip until we
+                        // see it.
 
                         let mut index = 0;
                         for i in 0..(cursor_index + 1) {
@@ -211,7 +213,8 @@ impl AppSearchState {
             Ok(_) => {}
             Err(err) => match err {
                 GraphemeIncomplete::PreContext(ctx) => {
-                    // Provide the entire string as context. Not efficient but should resolve failures.
+                    // Provide the entire string as context. Not efficient but should resolve
+                    // failures.
                     self.grapheme_cursor
                         .provide_context(&self.current_search_query[0..ctx], 0);
 
@@ -219,7 +222,7 @@ impl AppSearchState {
                         .next_boundary(chunk, start_position)
                         .unwrap();
                 }
-                _ => Err(err).unwrap(),
+                _ => panic!("{err:?}"),
             },
         }
     }
@@ -233,13 +236,14 @@ impl AppSearchState {
             Ok(_) => {}
             Err(err) => match err {
                 GraphemeIncomplete::PreContext(ctx) => {
-                    // Provide the entire string as context. Not efficient but should resolve failures.
+                    // Provide the entire string as context. Not efficient but should resolve
+                    // failures.
                     self.grapheme_cursor
                         .provide_context(&self.current_search_query[0..ctx], 0);
 
                     self.grapheme_cursor.prev_boundary(chunk, 0).unwrap();
                 }
-                _ => Err(err).unwrap(),
+                _ => panic!("{err:?}"),
             },
         }
     }
@@ -250,7 +254,7 @@ impl AppSearchState {
         for (index, grapheme) in
             UnicodeSegmentation::grapheme_indices(self.current_search_query.as_str(), true)
         {
-            let width = str_width(grapheme);
+            let width = grapheme_width(grapheme);
             let end = curr_offset + width;
 
             self.size_mappings.insert(index, curr_offset..end);
