@@ -2,7 +2,6 @@
 use std::cmp::min;
 
 use tui::{
-    backend::Backend,
     layout::{Alignment, Constraint, Direction, Layout, Rect},
     terminal::Frame,
     text::{Line, Span, Text},
@@ -183,19 +182,19 @@ impl Painter {
                     {
                         if to_kill_processes.1.len() != 1 {
                             Line::from(format!(
-                                "Kill {} processes with the name \"{}\"?  Press ENTER to confirm.",
+                                "Kill {} processes with the name '{}'?  Press ENTER to confirm.",
                                 to_kill_processes.1.len(),
                                 to_kill_processes.0
                             ))
                         } else {
                             Line::from(format!(
-                                "Kill 1 process with the name \"{}\"?  Press ENTER to confirm.",
+                                "Kill 1 process with the name '{}'?  Press ENTER to confirm.",
                                 to_kill_processes.0
                             ))
                         }
                     } else {
                         Line::from(format!(
-                            "Kill process \"{}\" with PID {}?  Press ENTER to confirm.",
+                            "Kill process '{}' with PID {}?  Press ENTER to confirm.",
                             to_kill_processes.0, first_pid
                         ))
                     },
@@ -206,18 +205,18 @@ impl Painter {
         None
     }
 
-    fn draw_dd_confirm_buttons<B: Backend>(
-        &self, f: &mut Frame<'_, B>, button_draw_loc: &Rect, app_state: &mut App,
+    fn draw_dd_confirm_buttons(
+        &self, f: &mut Frame<'_>, button_draw_loc: &Rect, app_state: &mut App,
     ) {
         if MAX_PROCESS_SIGNAL == 1 || !app_state.app_config_fields.is_advanced_kill {
             let (yes_button, no_button) = match app_state.delete_dialog_state.selected_signal {
                 KillSignal::Kill(_) => (
-                    Span::styled("Yes", self.colours.currently_selected_text_style),
+                    Span::styled("Yes", self.colours.selected_text_style),
                     Span::styled("No", self.colours.text_style),
                 ),
                 KillSignal::Cancel => (
                     Span::styled("Yes", self.colours.text_style),
-                    Span::styled("No", self.colours.currently_selected_text_style),
+                    Span::styled("No", self.colours.selected_text_style),
                 ),
             };
 
@@ -247,15 +246,18 @@ impl Painter {
             );
 
             if app_state.should_get_widget_bounds() {
+                const SIGNAL: usize = if cfg!(target_os = "windows") { 1 } else { 15 };
+
                 // This is kinda weird, but the gist is:
-                // - We have three sections; we put our mouse bounding box for the "yes" button at the very right edge
-                //   of the left section and 3 characters back.  We then give it a buffer size of 1 on the x-coordinate.
-                // - Same for the "no" button, except it is the right section and we do it from the start of the right
-                //   section.
+                // - We have three sections; we put our mouse bounding box for the "yes" button
+                //   at the very right edge of the left section and 3 characters back.  We then
+                //   give it a buffer size of 1 on the x-coordinate.
+                // - Same for the "no" button, except it is the right section and we do it from
+                //   the start of the right section.
                 //
-                // Lastly, note that mouse detection for the dd buttons assume correct widths.  As such, we correct
-                // them here and check with >= and <= mouse bound checks, as opposed to how we do it elsewhere with
-                // >= and <.  See https://github.com/ClementTsang/bottom/pull/459 for details.
+                // Lastly, note that mouse detection for the dd buttons assume correct widths.
+                // As such, we correct them here and check with >= and <= mouse
+                // bound checks, as opposed to how we do it elsewhere with >= and <.  See https://github.com/ClementTsang/bottom/pull/459 for details.
                 app_state.delete_dialog_state.button_positions = vec![
                     // Yes
                     (
@@ -263,7 +265,7 @@ impl Painter {
                         button_layout[0].y,
                         button_layout[0].x + button_layout[0].width,
                         button_layout[0].y,
-                        if cfg!(target_os = "windows") { 1 } else { 15 },
+                        SIGNAL,
                     ),
                     // No
                     (
@@ -323,10 +325,8 @@ impl Painter {
                     .map(|text| Span::styled(*text, self.colours.text_style))
                     .collect::<Vec<Span<'_>>>();
                 buttons.insert(0, Span::styled(SIGNAL_TEXT[0], self.colours.text_style));
-                buttons[selected - scroll_offset] = Span::styled(
-                    SIGNAL_TEXT[selected],
-                    self.colours.currently_selected_text_style,
-                );
+                buttons[selected - scroll_offset] =
+                    Span::styled(SIGNAL_TEXT[selected], self.colours.selected_text_style);
 
                 app_state.delete_dialog_state.button_positions = layout
                     .iter()
@@ -349,8 +349,8 @@ impl Painter {
         }
     }
 
-    pub fn draw_dd_dialog<B: Backend>(
-        &self, f: &mut Frame<'_, B>, dd_text: Option<Text<'_>>, app_state: &mut App, draw_loc: Rect,
+    pub fn draw_dd_dialog(
+        &self, f: &mut Frame<'_>, dd_text: Option<Text<'_>>, app_state: &mut App, draw_loc: Rect,
     ) -> bool {
         if let Some(dd_text) = dd_text {
             let dd_title = if app_state.dd_err.is_some() {
