@@ -1,8 +1,6 @@
 use std::borrow::Cow;
 
-use concat_string::concat_string;
 use tui::{
-    backend::Backend,
     layout::{Constraint, Direction, Layout, Rect},
     symbols::Marker,
     terminal::Frame,
@@ -10,10 +8,13 @@ use tui::{
 
 use crate::{
     app::{layout_manager::WidgetDirection, App},
-    canvas::{drawing_utils::should_hide_x_label, Painter},
-    components::{
-        data_table::{DrawInfo, SelectionState},
-        time_graph::{GraphData, TimeGraph},
+    canvas::{
+        components::{
+            data_table::{DrawInfo, SelectionState},
+            time_graph::{GraphData, TimeGraph},
+        },
+        drawing_utils::should_hide_x_label,
+        Painter,
     },
     data_conversion::CpuWidgetData,
     widgets::CpuWidgetState,
@@ -23,15 +24,13 @@ const AVG_POSITION: usize = 1;
 const ALL_POSITION: usize = 0;
 
 impl Painter {
-    pub fn draw_cpu<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
-    ) {
+    pub fn draw_cpu(&self, f: &mut Frame<'_>, app_state: &mut App, draw_loc: Rect, widget_id: u64) {
         let legend_width = (draw_loc.width as f64 * 0.15) as u16;
 
         if legend_width < 6 {
             // Skip drawing legend
             if app_state.current_widget.widget_id == (widget_id + 1) {
-                if app_state.app_config_fields.left_legend {
+                if app_state.app_config_fields.cpu_left_legend {
                     app_state.move_widget_selection(&WidgetDirection::Right);
                 } else {
                     app_state.move_widget_selection(&WidgetDirection::Left);
@@ -55,7 +54,7 @@ impl Painter {
         } else {
             let graph_width = draw_loc.width - legend_width;
             let (graph_index, legend_index, constraints) =
-                if app_state.app_config_fields.left_legend {
+                if app_state.app_config_fields.cpu_left_legend {
                     (
                         1,
                         0,
@@ -137,9 +136,9 @@ impl Painter {
                         CpuWidgetData::All => None,
                         CpuWidgetData::Entry { data, .. } => {
                             let style = if show_avg_cpu && itx == AVG_POSITION {
-                                self.colours.avg_colour_style
+                                self.colours.avg_cpu_colour
                             } else if itx == ALL_POSITION {
-                                self.colours.all_colour_style
+                                self.colours.all_cpu_colour
                             } else {
                                 let offset_position = itx - 1; // Because of the all position
                                 self.colours.cpu_colour_styles[(offset_position - show_avg_offset)
@@ -159,7 +158,7 @@ impl Painter {
             cpu_data.get(current_scroll_position)
         {
             let style = if show_avg_cpu && current_scroll_position == AVG_POSITION {
-                self.colours.avg_colour_style
+                self.colours.avg_cpu_colour
             } else {
                 let offset_position = current_scroll_position - 1; // Because of the all position
                 self.colours.cpu_colour_styles
@@ -176,8 +175,8 @@ impl Painter {
         }
     }
 
-    fn draw_cpu_graph<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
+    fn draw_cpu_graph(
+        &self, f: &mut Frame<'_>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
     ) {
         const Y_BOUNDS: [f64; 2] = [0.0, 100.5];
         const Y_LABELS: [Cow<'static, str>; 2] = [Cow::Borrowed("  0%"), Cow::Borrowed("100%")];
@@ -201,16 +200,21 @@ impl Painter {
             );
 
             // TODO: Maybe hide load avg if too long? Or maybe the CPU part.
-            let title = if cfg!(target_family = "unix") {
-                let load_avg = app_state.converted_data.load_avg_data;
-                let load_avg_str = format!(
-                    "─ {:.2} {:.2} {:.2} ",
-                    load_avg[0], load_avg[1], load_avg[2]
-                );
+            let title = {
+                #[cfg(target_family = "unix")]
+                {
+                    let load_avg = app_state.converted_data.load_avg_data;
+                    let load_avg_str = format!(
+                        "─ {:.2} {:.2} {:.2} ",
+                        load_avg[0], load_avg[1], load_avg[2]
+                    );
 
-                concat_string!(" CPU ", load_avg_str).into()
-            } else {
-                " CPU ".into()
+                    concat_string::concat_string!(" CPU ", load_avg_str).into()
+                }
+                #[cfg(not(target_family = "unix"))]
+                {
+                    " CPU ".into()
+                }
             };
 
             let marker = if app_state.app_config_fields.use_dot {
@@ -229,6 +233,7 @@ impl Painter {
                 title,
                 is_expanded: app_state.is_expanded,
                 title_style: self.colours.widget_title_style,
+                legend_position: None,
                 legend_constraints: None,
                 marker,
             }
@@ -236,8 +241,8 @@ impl Painter {
         }
     }
 
-    fn draw_cpu_legend<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
+    fn draw_cpu_legend(
+        &self, f: &mut Frame<'_>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
     ) {
         let recalculate_column_widths = app_state.should_get_widget_bounds();
         if let Some(cpu_widget_state) = app_state
@@ -246,7 +251,8 @@ impl Painter {
             .widget_states
             .get_mut(&(widget_id - 1))
         {
-            // TODO: This line (and the one above, see caller) is pretty dumb but I guess needed for now. Refactor if possible!
+            // TODO: This line (and the one above, see caller) is pretty dumb but I guess
+            // needed for now. Refactor if possible!
             cpu_widget_state.is_legend_hidden = false;
 
             let is_on_widget = widget_id == app_state.current_widget.widget_id;
