@@ -1,17 +1,24 @@
-use tui::{backend::Backend, layout::Rect, terminal::Frame};
+use tui::{layout::Rect, terminal::Frame};
 
 use crate::{
-    app::{self},
-    canvas::Painter,
-    components::data_table::{DrawInfo, SelectionState},
+    app,
+    canvas::{
+        components::data_table::{DrawInfo, SelectionState},
+        Painter,
+    },
 };
 
 impl Painter {
-    pub fn draw_disk_table<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut app::App, draw_loc: Rect, widget_id: u64,
+    pub fn draw_disk_table(
+        &self, f: &mut Frame<'_>, app_state: &mut app::App, draw_loc: Rect, widget_id: u64,
     ) {
         let recalculate_column_widths = app_state.should_get_widget_bounds();
-        if let Some(disk_widget_state) = app_state.disk_state.widget_states.get_mut(&widget_id) {
+        if let Some(disk_widget_state) = app_state
+            .states
+            .disk_state
+            .widget_states
+            .get_mut(&widget_id)
+        {
             let is_on_widget = app_state.current_widget.widget_id == widget_id;
 
             let draw_info = DrawInfo {
