@@ -1,7 +1,6 @@
 use std::borrow::Cow;
 
 use tui::{
-    backend::Backend,
     layout::{Constraint, Rect},
     symbols::Marker,
     terminal::Frame,
@@ -9,18 +8,22 @@ use tui::{
 
 use crate::{
     app::App,
-    canvas::{drawing_utils::should_hide_x_label, Painter},
-    components::time_graph::{GraphData, TimeGraph},
+    canvas::{
+        components::time_graph::{GraphData, TimeGraph},
+        drawing_utils::should_hide_x_label,
+        Painter,
+    },
 };
 
 impl Painter {
-    pub fn draw_memory_graph<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
+    pub fn draw_memory_graph(
+        &self, f: &mut Frame<'_>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
     ) {
         const Y_BOUNDS: [f64; 2] = [0.0, 100.5];
         const Y_LABELS: [Cow<'static, str>; 2] = [Cow::Borrowed("  0%"), Cow::Borrowed("100%")];
 
-        if let Some(mem_widget_state) = app_state.mem_state.widget_states.get_mut(&widget_id) {
+        if let Some(mem_widget_state) = app_state.states.mem_state.widget_states.get_mut(&widget_id)
+        {
             let border_style = self.get_border_style(widget_id, app_state.current_widget.widget_id);
             let x_bounds = [0, mem_widget_state.current_display_time];
             let hide_x_labels = should_hide_x_label(
@@ -49,7 +52,7 @@ impl Painter {
 
                 let mut points = Vec::with_capacity(size);
                 if let Some((label_percent, label_frac)) = &app_state.converted_data.mem_labels {
-                    let mem_label = format!("RAM:{}{}", label_percent, label_frac);
+                    let mem_label = format!("RAM:{label_percent}{label_frac}");
                     points.push(GraphData {
                         points: &app_state.converted_data.mem_data,
                         style: self.colours.ram_style,
@@ -58,7 +61,7 @@ impl Painter {
                 }
                 #[cfg(not(target_os = "windows"))]
                 if let Some((label_percent, label_frac)) = &app_state.converted_data.cache_labels {
-                    let cache_label = format!("CHE:{}{}", label_percent, label_frac);
+                    let cache_label = format!("CHE:{label_percent}{label_frac}");
                     points.push(GraphData {
                         points: &app_state.converted_data.cache_data,
                         style: self.colours.cache_style,
@@ -66,7 +69,7 @@ impl Painter {
                     });
                 }
                 if let Some((label_percent, label_frac)) = &app_state.converted_data.swap_labels {
-                    let swap_label = format!("SWP:{}{}", label_percent, label_frac);
+                    let swap_label = format!("SWP:{label_percent}{label_frac}");
                     points.push(GraphData {
                         points: &app_state.converted_data.swap_data,
                         style: self.colours.swap_style,
@@ -75,7 +78,7 @@ impl Painter {
                 }
                 #[cfg(feature = "zfs")]
                 if let Some((label_percent, label_frac)) = &app_state.converted_data.arc_labels {
-                    let arc_label = format!("ARC:{}{}", label_percent, label_frac);
+                    let arc_label = format!("ARC:{label_percent}{label_frac}");
                     points.push(GraphData {
                         points: &app_state.converted_data.arc_data,
                         style: self.colours.arc_style,
@@ -86,7 +89,7 @@ impl Painter {
                 {
                     if let Some(gpu_data) = &app_state.converted_data.gpu_data {
                         let mut color_index = 0;
-                        let gpu_styles = &self.colours.gpu_colour_styles;
+                        let gpu_styles = &self.colours.gpu_colours;
                         gpu_data.iter().for_each(|gpu| {
                             let gpu_label =
                                 format!("{}:{}{}", gpu.name, gpu.mem_percent, gpu.mem_total);
@@ -130,6 +133,7 @@ impl Painter {
                 title: " Memory ".into(),
                 is_expanded: app_state.is_expanded,
                 title_style: self.colours.widget_title_style,
+                legend_position: app_state.app_config_fields.memory_legend_position,
                 legend_constraints: Some((Constraint::Ratio(3, 4), Constraint::Ratio(3, 4))),
                 marker,
             }
