@@ -1,5 +1,4 @@
 use tui::{
-    backend::Backend,
     layout::{Constraint, Direction, Layout, Rect},
     symbols::Marker,
     terminal::Frame,
@@ -9,17 +8,20 @@ use tui::{
 
 use crate::{
     app::{App, AxisScaling},
-    canvas::{drawing_utils::should_hide_x_label, Painter},
-    components::{
-        time_graph::{GraphData, TimeGraph},
-        tui_widget::time_chart::Point,
+    canvas::{
+        components::{
+            time_chart::Point,
+            time_graph::{GraphData, TimeGraph},
+        },
+        drawing_utils::should_hide_x_label,
+        Painter,
     },
-    utils::{data_units::DataUnit, gen_util::*},
+    utils::{data_prefixes::*, data_units::DataUnit, general::partial_ordering},
 };
 
 impl Painter {
-    pub fn draw_network<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
+    pub fn draw_network(
+        &self, f: &mut Frame<'_>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
     ) {
         if app_state.app_config_fields.use_old_network_legend {
             const LEGEND_HEIGHT: u16 = 4;
@@ -40,8 +42,8 @@ impl Painter {
 
         if app_state.should_get_widget_bounds() {
             // Update draw loc in widget map
-            // Note that in both cases, we always go to the same widget id so it's fine to do it like
-            // this lol.
+            // Note that in both cases, we always go to the same widget id so it's fine to
+            // do it like this lol.
             if let Some(network_widget) = app_state.widget_map.get_mut(&widget_id) {
                 network_widget.top_left_corner = Some((draw_loc.x, draw_loc.y));
                 network_widget.bottom_right_corner =
@@ -50,8 +52,8 @@ impl Painter {
         }
     }
 
-    pub fn draw_network_graph<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
+    pub fn draw_network_graph(
+        &self, f: &mut Frame<'_>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
         hide_legend: bool,
     ) {
         if let Some(network_widget_state) =
@@ -72,7 +74,8 @@ impl Painter {
             // TODO: Cache network results: Only update if:
             // - Force update (includes time interval change)
             // - Old max time is off screen
-            // - A new time interval is better and does not fit (check from end of vector to last checked; we only want to update if it is TOO big!)
+            // - A new time interval is better and does not fit (check from end of vector to
+            //   last checked; we only want to update if it is TOO big!)
 
             // Find the maximal rx/tx so we know how to scale, and return it.
             let (_best_time, max_entry) = get_max_entry(
@@ -160,6 +163,7 @@ impl Painter {
                 title: " Network ".into(),
                 is_expanded: app_state.is_expanded,
                 title_style: self.colours.widget_title_style,
+                legend_position: app_state.app_config_fields.network_legend_position,
                 legend_constraints: Some(legend_constraints),
                 marker,
             }
@@ -167,8 +171,8 @@ impl Painter {
         }
     }
 
-    fn draw_network_labels<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
+    fn draw_network_labels(
+        &self, f: &mut Frame<'_>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
     ) {
         const NETWORK_HEADERS: [&str; 4] = ["RX", "TX", "Total RX", "Total TX"];
 
@@ -178,7 +182,7 @@ impl Painter {
         let total_tx_display = &app_state.converted_data.total_tx_display;
 
         // Gross but I need it to work...
-        let total_network = vec![Row::new(vec![
+        let total_network = vec![Row::new([
             Text::styled(rx_display, self.colours.rx_style),
             Text::styled(tx_display, self.colours.tx_style),
             Text::styled(total_rx_display, self.colours.total_rx_style),
@@ -187,22 +191,22 @@ impl Painter {
 
         // Draw
         f.render_widget(
-            Table::new(total_network)
-                .header(Row::new(NETWORK_HEADERS.to_vec()).style(self.colours.table_header_style))
-                .block(Block::default().borders(Borders::ALL).border_style(
-                    if app_state.current_widget.widget_id == widget_id {
-                        self.colours.highlighted_border_style
-                    } else {
-                        self.colours.border_style
-                    },
-                ))
-                .style(self.colours.text_style)
-                .widths(
-                    &((std::iter::repeat(draw_loc.width.saturating_sub(2) / 4))
-                        .take(4)
-                        .map(Constraint::Length)
-                        .collect::<Vec<_>>()),
-                ),
+            Table::new(
+                total_network,
+                &((std::iter::repeat(draw_loc.width.saturating_sub(2) / 4))
+                    .take(4)
+                    .map(Constraint::Length)
+                    .collect::<Vec<_>>()),
+            )
+            .header(Row::new(NETWORK_HEADERS).style(self.colours.table_header_style))
+            .block(Block::default().borders(Borders::ALL).border_style(
+                if app_state.current_widget.widget_id == widget_id {
+                    self.colours.highlighted_border_style
+                } else {
+                    self.colours.border_style
+                },
+            ))
+            .style(self.colours.text_style),
             draw_loc,
         );
     }
@@ -213,7 +217,8 @@ fn get_max_entry(
     rx: &[Point], tx: &[Point], time_start: f64, network_scale_type: &AxisScaling,
     network_use_binary_prefix: bool,
 ) -> Point {
-    /// Determines a "fake" max value in circumstances where we couldn't find one from the data.
+    /// Determines a "fake" max value in circumstances where we couldn't find
+    /// one from the data.
     fn calculate_missing_max(
         network_scale_type: &AxisScaling, network_use_binary_prefix: bool,
     ) -> f64 {
@@ -235,8 +240,9 @@ fn get_max_entry(
         }
     }
 
-    // First, let's shorten our ranges to actually look.  We can abuse the fact that our rx and tx arrays
-    // are sorted, so we can short-circuit our search to filter out only the relevant data points...
+    // First, let's shorten our ranges to actually look.  We can abuse the fact that
+    // our rx and tx arrays are sorted, so we can short-circuit our search to
+    // filter out only the relevant data points...
     let filtered_rx = if let (Some(rx_start), Some(rx_end)) = (
         rx.iter().position(|(time, _data)| *time >= time_start),
         rx.iter().rposition(|(time, _data)| *time <= 0.0),
@@ -334,26 +340,31 @@ fn adjust_network_data_point(
     network_use_binary_prefix: bool,
 ) -> (f64, Vec<String>) {
     // So, we're going with an approach like this for linear data:
-    // - Main goal is to maximize the amount of information displayed given a specific height.
-    //   We don't want to drown out some data if the ranges are too far though!  Nor do we want to filter
-    //   out too much data...
-    // - Change the y-axis unit (kilo/kibi, mega/mebi...) dynamically based on max load.
+    // - Main goal is to maximize the amount of information displayed given a
+    //   specific height. We don't want to drown out some data if the ranges are too
+    //   far though!  Nor do we want to filter out too much data...
+    // - Change the y-axis unit (kilo/kibi, mega/mebi...) dynamically based on max
+    //   load.
     //
-    // The idea is we take the top value, build our scale such that each "point" is a scaled version of that.
-    // So for example, let's say I use 390 Mb/s.  If I drew 4 segments, it would be 97.5, 195, 292.5, 390, and
+    // The idea is we take the top value, build our scale such that each "point" is
+    // a scaled version of that. So for example, let's say I use 390 Mb/s.  If I
+    // drew 4 segments, it would be 97.5, 195, 292.5, 390, and
     // probably something like 438.75?
     //
-    // So, how do we do this in tui-rs?  Well, if we  are using intervals that tie in perfectly to the max
-    // value we want... then it's actually not that hard.  Since tui-rs accepts a vector as labels and will
-    // properly space them all out... we just work with that and space it out properly.
+    // So, how do we do this in ratatui?  Well, if we  are using intervals that tie
+    // in perfectly to the max value we want... then it's actually not that
+    // hard.  Since ratatui accepts a vector as labels and will properly space
+    // them all out... we just work with that and space it out properly.
     //
     // Dynamic chart idea based off of FreeNAS's chart design.
     //
     // ===
     //
-    // For log data, we just use the old method of log intervals (kilo/mega/giga/etc.).  Keep it nice and simple.
+    // For log data, we just use the old method of log intervals
+    // (kilo/mega/giga/etc.).  Keep it nice and simple.
 
-    // Now just check the largest unit we correspond to... then proceed to build some entries from there!
+    // Now just check the largest unit we correspond to... then proceed to build
+    // some entries from there!
 
     let unit_char = match network_unit_type {
         DataUnit::Byte => "B",
@@ -408,18 +419,20 @@ fn adjust_network_data_point(
                     )
                 };
 
-            // Finally, build an acceptable range starting from there, using the given height!
-            // Note we try to put more of a weight on the bottom section vs. the top, since the top has less data.
+            // Finally, build an acceptable range starting from there, using the given
+            // height! Note we try to put more of a weight on the bottom section
+            // vs. the top, since the top has less data.
 
             let base_unit = max_value_scaled;
             let labels: Vec<String> = vec![
-                format!("0{}{}", unit_prefix, unit_type),
+                format!("0{unit_prefix}{unit_type}"),
                 format!("{:.1}", base_unit * 0.5),
                 format!("{:.1}", base_unit),
                 format!("{:.1}", base_unit * 1.5),
             ]
             .into_iter()
-            .map(|s| format!("{:>5}", s)) // Pull 5 as the longest legend value is generally going to be 5 digits (if they somehow hit over 5 terabits per second)
+            .map(|s| format!("{s:>5}")) // Pull 5 as the longest legend value is generally going to be 5 digits (if they somehow
+            // hit over 5 terabits per second)
             .collect();
 
             (bumped_max_entry, labels)
