@@ -1,8 +1,5 @@
-use once_cell::sync::Lazy;
 use tui::widgets::Borders;
 
-use crate::options::ConfigColours;
-
 // Default widget ID
 pub const DEFAULT_WIDGET_ID: u64 = 56709;
 
@@ -17,259 +14,13 @@ pub const TICK_RATE_IN_MILLISECONDS: u64 = 200;
 pub const DEFAULT_REFRESH_RATE_IN_MILLISECONDS: u64 = 1000;
 pub const MAX_KEY_TIMEOUT_IN_MILLISECONDS: u64 = 1000;
 
-// Limits for when we should stop showing table gaps/labels (anything less means not shown)
+// Limits for when we should stop showing table gaps/labels (anything less means
+// not shown)
 pub const TABLE_GAP_HEIGHT_LIMIT: u16 = 7;
 pub const TIME_LABEL_HEIGHT_LIMIT: u16 = 7;
 
 // Side borders
 pub const SIDE_BORDERS: Borders = Borders::LEFT.union(Borders::RIGHT);
-pub static DEFAULT_TEXT_STYLE: Lazy<tui::style::Style> =
-    Lazy::new(|| tui::style::Style::default().fg(tui::style::Color::Gray));
-pub static DEFAULT_HEADER_STYLE: Lazy<tui::style::Style> =
-    Lazy::new(|| tui::style::Style::default().fg(tui::style::Color::LightBlue));
-
-// Colour profiles
-pub static DEFAULT_LIGHT_MODE_COLOUR_PALETTE: Lazy<ConfigColours> = Lazy::new(|| ConfigColours {
-    text_color: Some("black".into()),
-    border_color: Some("black".into()),
-    table_header_color: Some("black".into()),
-    widget_title_color: Some("black".into()),
-    selected_text_color: Some("white".into()),
-    graph_color: Some("black".into()),
-    disabled_text_color: Some("gray".into()),
-    ram_color: Some("blue".into()),
-    #[cfg(not(target_os = "windows"))]
-    cache_color: Some("LightRed".into()),
-    swap_color: Some("red".into()),
-    arc_color: Some("LightBlue".into()),
-    gpu_core_colors: Some(vec![
-        "LightGreen".into(),
-        "LightCyan".into(),
-        "LightRed".into(),
-        "Cyan".into(),
-        "Green".into(),
-        "Blue".into(),
-        "Red".into(),
-    ]),
-    rx_color: Some("blue".into()),
-    tx_color: Some("red".into()),
-    rx_total_color: Some("LightBlue".into()),
-    tx_total_color: Some("LightRed".into()),
-    cpu_core_colors: Some(vec![
-        "LightMagenta".into(),
-        "LightBlue".into(),
-        "LightRed".into(),
-        "Cyan".into(),
-        "Green".into(),
-        "Blue".into(),
-        "Red".into(),
-    ]),
-    ..ConfigColours::default()
-});
-
-pub static GRUVBOX_COLOUR_PALETTE: Lazy<ConfigColours> = Lazy::new(|| ConfigColours {
-    table_header_color: Some("#83a598".into()),
-    all_cpu_color: Some("#8ec07c".into()),
-    avg_cpu_color: Some("#fb4934".into()),
-    cpu_core_colors: Some(vec![
-        "#cc241d".into(),
-        "#98971a".into(),
-        "#d79921".into(),
-        "#458588".into(),
-        "#b16286".into(),
-        "#689d6a".into(),
-        "#fe8019".into(),
-        "#b8bb26".into(),
-        "#fabd2f".into(),
-        "#83a598".into(),
-        "#d3869b".into(),
-        "#d65d0e".into(),
-        "#9d0006".into(),
-        "#79740e".into(),
-        "#b57614".into(),
-        "#076678".into(),
-        "#8f3f71".into(),
-        "#427b58".into(),
-        "#d65d03".into(),
-        "#af3a03".into(),
-    ]),
-    ram_color: Some("#8ec07c".into()),
-    #[cfg(not(target_os = "windows"))]
-    cache_color: Some("#b16286".into()),
-    swap_color: Some("#fabd2f".into()),
-    arc_color: Some("#689d6a".into()),
-    gpu_core_colors: Some(vec![
-        "#d79921".into(),
-        "#458588".into(),
-        "#b16286".into(),
-        "#fe8019".into(),
-        "#b8bb26".into(),
-        "#cc241d".into(),
-        "#98971a".into(),
-    ]),
-    rx_color: Some("#8ec07c".into()),
-    tx_color: Some("#fabd2f".into()),
-    rx_total_color: Some("#689d6a".into()),
-    tx_total_color: Some("#d79921".into()),
-    border_color: Some("#ebdbb2".into()),
-    highlighted_border_color: Some("#fe8019".into()),
-    disabled_text_color: Some("#665c54".into()),
-    text_color: Some("#ebdbb2".into()),
-    selected_text_color: Some("#1d2021".into()),
-    selected_bg_color: Some("#ebdbb2".into()),
-    widget_title_color: Some("#ebdbb2".into()),
-    graph_color: Some("#ebdbb2".into()),
-    high_battery_color: Some("#98971a".into()),
-    medium_battery_color: Some("#fabd2f".into()),
-    low_battery_color: Some("#fb4934".into()),
-});
-
-pub static GRUVBOX_LIGHT_COLOUR_PALETTE: Lazy<ConfigColours> = Lazy::new(|| ConfigColours {
-    table_header_color: Some("#076678".into()),
-    all_cpu_color: Some("#8ec07c".into()),
-    avg_cpu_color: Some("#fb4934".into()),
-    cpu_core_colors: Some(vec![
-        "#cc241d".into(),
-        "#98971a".into(),
-        "#d79921".into(),
-        "#458588".into(),
-        "#b16286".into(),
-        "#689d6a".into(),
-        "#fe8019".into(),
-        "#b8bb26".into(),
-        "#fabd2f".into(),
-        "#83a598".into(),
-        "#d3869b".into(),
-        "#d65d0e".into(),
-        "#9d0006".into(),
-        "#79740e".into(),
-        "#b57614".into(),
-        "#076678".into(),
-        "#8f3f71".into(),
-        "#427b58".into(),
-        "#d65d03".into(),
-        "#af3a03".into(),
-    ]),
-    ram_color: Some("#427b58".into()),
-    #[cfg(not(target_os = "windows"))]
-    cache_color: Some("#d79921".into()),
-    swap_color: Some("#cc241d".into()),
-    arc_color: Some("#689d6a".into()),
-    gpu_core_colors: Some(vec![
-        "#9d0006".into(),
-        "#98971a".into(),
-        "#d79921".into(),
-        "#458588".into(),
-        "#b16286".into(),
-        "#fe8019".into(),
-        "#b8bb26".into(),
-    ]),
-    rx_color: Some("#427b58".into()),
-    tx_color: Some("#cc241d".into()),
-    rx_total_color: Some("#689d6a".into()),
-    tx_total_color: Some("#9d0006".into()),
-    border_color: Some("#3c3836".into()),
-    highlighted_border_color: Some("#af3a03".into()),
-    disabled_text_color: Some("#d5c4a1".into()),
-    text_color: Some("#3c3836".into()),
-    selected_text_color: Some("#ebdbb2".into()),
-    selected_bg_color: Some("#3c3836".into()),
-    widget_title_color: Some("#3c3836".into()),
-    graph_color: Some("#3c3836".into()),
-    high_battery_color: Some("#98971a".into()),
-    medium_battery_color: Some("#d79921".into()),
-    low_battery_color: Some("#cc241d".into()),
-});
-
-pub static NORD_COLOUR_PALETTE: Lazy<ConfigColours> = Lazy::new(|| ConfigColours {
-    table_header_color: Some("#81a1c1".into()),
-    all_cpu_color: Some("#88c0d0".into()),
-    avg_cpu_color: Some("#8fbcbb".into()),
-    cpu_core_colors: Some(vec![
-        "#5e81ac".into(),
-        "#81a1c1".into(),
-        "#d8dee9".into(),
-        "#b48ead".into(),
-        "#a3be8c".into(),
-        "#ebcb8b".into(),
-        "#d08770".into(),
-        "#bf616a".into(),
-    ]),
-    ram_color: Some("#88c0d0".into()),
-    #[cfg(not(target_os = "windows"))]
-    cache_color: Some("#d8dee9".into()),
-    swap_color: Some("#d08770".into()),
-    arc_color: Some("#5e81ac".into()),
-    gpu_core_colors: Some(vec![
-        "#8fbcbb".into(),
-        "#81a1c1".into(),
-        "#d8dee9".into(),
-        "#b48ead".into(),
-        "#a3be8c".into(),
-        "#ebcb8b".into(),
-        "#bf616a".into(),
-    ]),
-    rx_color: Some("#88c0d0".into()),
-    tx_color: Some("#d08770".into()),
-    rx_total_color: Some("#5e81ac".into()),
-    tx_total_color: Some("#8fbcbb".into()),
-    border_color: Some("#88c0d0".into()),
-    highlighted_border_color: Some("#5e81ac".into()),
-    disabled_text_color: Some("#4c566a".into()),
-    text_color: Some("#e5e9f0".into()),
-    selected_text_color: Some("#2e3440".into()),
-    selected_bg_color: Some("#88c0d0".into()),
-    widget_title_color: Some("#e5e9f0".into()),
-    graph_color: Some("#e5e9f0".into()),
-    high_battery_color: Some("#a3be8c".into()),
-    medium_battery_color: Some("#ebcb8b".into()),
-    low_battery_color: Some("#bf616a".into()),
-});
-
-pub static NORD_LIGHT_COLOUR_PALETTE: Lazy<ConfigColours> = Lazy::new(|| ConfigColours {
-    table_header_color: Some("#5e81ac".into()),
-    all_cpu_color: Some("#81a1c1".into()),
-    avg_cpu_color: Some("#8fbcbb".into()),
-    cpu_core_colors: Some(vec![
-        "#5e81ac".into(),
-        "#88c0d0".into(),
-        "#4c566a".into(),
-        "#b48ead".into(),
-        "#a3be8c".into(),
-        "#ebcb8b".into(),
-        "#d08770".into(),
-        "#bf616a".into(),
-    ]),
-    ram_color: Some("#81a1c1".into()),
-    #[cfg(not(target_os = "windows"))]
-    cache_color: Some("#4c566a".into()),
-    swap_color: Some("#d08770".into()),
-    arc_color: Some("#5e81ac".into()),
-    gpu_core_colors: Some(vec![
-        "#8fbcbb".into(),
-        "#88c0d0".into(),
-        "#4c566a".into(),
-        "#b48ead".into(),
-        "#a3be8c".into(),
-        "#ebcb8b".into(),
-        "#bf616a".into(),
-    ]),
-    rx_color: Some("#81a1c1".into()),
-    tx_color: Some("#d08770".into()),
-    rx_total_color: Some("#5e81ac".into()),
-    tx_total_color: Some("#8fbcbb".into()),
-    border_color: Some("#2e3440".into()),
-    highlighted_border_color: Some("#5e81ac".into()),
-    disabled_text_color: Some("#d8dee9".into()),
-    text_color: Some("#2e3440".into()),
-    selected_text_color: Some("#f5f5f5".into()),
-    selected_bg_color: Some("#5e81ac".into()),
-    widget_title_color: Some("#2e3440".into()),
-    graph_color: Some("#2e3440".into()),
-    high_battery_color: Some("#a3be8c".into()),
-    medium_battery_color: Some("#ebcb8b".into()),
-    low_battery_color: Some("#bf616a".into()),
-});
 
 // Help text
 pub const HELP_CONTENTS_TEXT: [&str; 10] = [
@@ -327,7 +78,7 @@ pub const CPU_HELP_TEXT: [&str; 2] = [
     "Mouse scroll     Scrolling over an CPU core/average shows only that entry on the chart",
 ];
 
-pub const PROCESS_HELP_TEXT: [&str; 15] = [
+pub const PROCESS_HELP_TEXT: [&str; 17] = [
     "3 - Process widget",
     "dd, F9           Kill the selected process",
     "c                Sort by CPU usage, press again to reverse",
@@ -343,9 +94,11 @@ pub const PROCESS_HELP_TEXT: [&str; 15] = [
     "t, F5            Toggle tree mode",
     "+, -, click      Collapse/expand a branch while in tree mode",
     "click on header  Sorts the entries by that column, click again to invert the sort",
+    "C                Sort by GPU usage, press again to reverse",
+    "M                Sort by GPU memory usage, press again to reverse",
 ];
 
-pub const SEARCH_HELP_TEXT: [&str; 48] = [
+pub const SEARCH_HELP_TEXT: [&str; 51] = [
     "4 - Process search widget",
     "Esc              Close the search widget (retains the filter)",
     "Ctrl-a           Skip to the start of the search query",
@@ -373,6 +126,9 @@ pub const SEARCH_HELP_TEXT: [&str; 48] = [
     "twrite, t.write  ex: twrite = 1",
     "user             ex: user = root",
     "state            ex: state = running",
+    "gpu%             ex: gpu% < 4.2",
+    "gmem             ex: gmem < 100 kb",
+    "gmem%            ex: gmem% < 4.2",
     "",
     "Comparison operators:",
     "=                ex: cpu = 1",
@@ -448,7 +204,7 @@ pub const HELP_TEXT: [&[&str]; HELP_CONTENTS_TEXT.len()] = [
 ];
 
 // Default layouts
-pub const DEFAULT_LAYOUT: &str = r##"
+pub const DEFAULT_LAYOUT: &str = r#"
 [[row]]
   ratio=30
   [[row.child]]
@@ -471,9 +227,9 @@ pub const DEFAULT_LAYOUT: &str = r##"
   [[row.child]]
     type="proc"
     default=true
-"##;
+"#;
 
-pub const DEFAULT_BATTERY_LAYOUT: &str = r##"
+pub const DEFAULT_BATTERY_LAYOUT: &str = r#"
 [[row]]
   ratio=30
   [[row.child]]
@@ -500,20 +256,18 @@ pub const DEFAULT_BATTERY_LAYOUT: &str = r##"
   [[row.child]]
     type="proc"
     default=true
-"##;
+"#;
 
 // Config and flags
-pub const DEFAULT_CONFIG_FILE_PATH: &str = "bottom/bottom.toml";
 
 // TODO: Eventually deprecate this, or grab from a file.
-pub const CONFIG_TEXT: &str = r##"# This is a default config file for bottom.  All of the settings are commented
+pub const CONFIG_TEXT: &str = r#"# This is a default config file for bottom.  All of the settings are commented
 # out by default; if you wish to change them uncomment and modify as you see
 # fit.
 
-# This group of options represents a command-line flag/option.  Flags explicitly
+# This group of options represents a command-line option.  Flags explicitly
 # added when running (ie: btm -a) will override this config file if an option
 # is also set here.
-
 [flags]
 # Whether to hide the average cpu entry.
 #hide_avg_cpu = false
@@ -522,7 +276,7 @@ pub const CONFIG_TEXT: &str = r##"# This is a default config file for bottom.  A
 # The update rate of the application.
 #rate = "1s"
 # Whether to put the CPU legend to the left.
-#left_legend = false
+#cpu_left_legend = false
 # Whether to set CPU% on a process to be based on the total CPU or just current usage.
 #current_usage = false
 # Whether to set CPU% on a process to be based on the total CPU or per-core CPU% (not divided by the number of cpus).
@@ -535,13 +289,13 @@ pub const CONFIG_TEXT: &str = r##"# This is a default config file for bottom.  A
 #whole_word = false
 # Whether to make process searching use regex by default.
 #regex = false
-# Defaults to Celsius.  Temperature is one of:
-#temperature_type = "k"
-#temperature_type = "f"
+# The temperature unit. One of the following, defaults to "c" for Celsius:
 #temperature_type = "c"
-#temperature_type = "kelvin"
-#temperature_type = "fahrenheit"
-#temperature_type = "celsius"
+##temperature_type = "k"
+##temperature_type = "f"
+##temperature_type = "kelvin"
+##temperature_type = "fahrenheit"
+##temperature_type = "celsius"
 # The default time interval (in milliseconds).
 #default_time_value = "60s"
 # The time delta on each zoom in/out action (in milliseconds).
@@ -552,7 +306,7 @@ pub const CONFIG_TEXT: &str = r##"# This is a default config file for bottom.  A
 #default_widget_type = "proc"
 #default_widget_count = 1
 # Expand selected widget upon starting the app
-#expanded_on_startup = true
+#expanded = true
 # Use basic mode
 #basic = false
 # Use the old network legend style
@@ -563,10 +317,8 @@ pub const CONFIG_TEXT: &str = r##"# This is a default config file for bottom.  A
 #battery = false
 # Disable mouse clicks
 #disable_click = false
-# Built-in themes.  Valid values are "default", "default-light", "gruvbox", "gruvbox-light", "nord", "nord-light"
-#color = "default"
 # Show memory values in the processes widget as values by default
-#mem_as_value = false
+#process_memory_as_value = false
 # Show tree mode by default in the processes widget.
 #tree = false
 # Shows an indicator in table widgets tracking where in the list you are.
@@ -581,58 +333,115 @@ pub const CONFIG_TEXT: &str = r##"# This is a default config file for bottom.  A
 #network_use_log = false
 # Hides advanced options to stop a process on Unix-like systems.
 #disable_advanced_kill = false
-# Shows GPU(s) memory
-#enable_gpu_memory = false
+# Shows GPU(s) information
+#enable_gpu = false
 # Shows cache and buffer memory
 #enable_cache_memory = false
 # How much data is stored at once in terms of time.
 #retention = "10m"
+# Where to place the legend for the memory widget. One of "none", "top-left", "top", "top-right", "left", "right", "bottom-left", "bottom", "bottom-right".
+#memory_legend = "TopRight".
+# Where to place the legend for the network widget. One of "none", "top-left", "top", "top-right", "left", "right", "bottom-left", "bottom", "bottom-right".
+#network_legend = "TopRight".
 
-# These are flags around the process widget.
-
+# Processes widget configuration
 #[processes]
-#columns = ["PID", "Name", "CPU%", "Mem%", "R/s", "W/s", "T.Read", "T.Write", "User", "State"]
+# The columns shown by the process widget. The following columns are supported:
+# PID, Name, CPU%, Mem%, R/s, W/s, T.Read, T.Write, User, State, Time, GMem%, GPU%
+#columns = ["PID", "Name", "CPU%", "Mem%", "R/s", "W/s", "T.Read", "T.Write", "User", "State", "GMem%", "GPU%"]
+
+# CPU widget configuration
+#[cpu]
+# One of "all" (default), "average"/"avg"
+# default = "average"
+
+# Disk widget configuration
+#[disk]
+#[name_filter]
+#is_list_ignored = true
+#list = ["/dev/sda\\d+", "/dev/nvme0n1p2"]
+#regex = true
+#case_sensitive = false
+#whole_word = false
+
+#[mount_filter]
+#is_list_ignored = true
+#list = ["/mnt/.*", "/boot"]
+#regex = true
+#case_sensitive = false
+#whole_word = false
+
+# Temperature widget configuration
+#[temperature]
+#[sensor_filter]
+#is_list_ignored = true
+#list = ["cpu", "wifi"]
+#regex = false
+#case_sensitive = false
+#whole_word = false
+
+# Network widget configuration
+#[network]
+#[interface_filter]
+#is_list_ignored = true
+#list = ["virbr0.*"]
+#regex = true
+#case_sensitive = false
+#whole_word = false
 
 # These are all the components that support custom theming.  Note that colour support
 # will depend on terminal support.
+#[styles] # Uncomment if you want to use custom styling
 
-#[colors] # Uncomment if you want to use custom colors
-# Represents the colour of table headers (processes, CPU, disks, temperature).
-#table_header_color="LightBlue"
-# Represents the colour of the label each widget has.
-#widget_title_color="Gray"
-# Represents the average CPU color.
-#avg_cpu_color="Red"
-# Represents the colour the core will use in the CPU legend and graph.
-#cpu_core_colors=["LightMagenta", "LightYellow", "LightCyan", "LightGreen", "LightBlue", "LightRed", "Cyan", "Green", "Blue", "Red"]
-# Represents the colour RAM will use in the memory legend and graph.
-#ram_color="LightMagenta"
-# Represents the colour SWAP will use in the memory legend and graph.
-#swap_color="LightYellow"
-# Represents the colour ARC will use in the memory legend and graph.
-#arc_color="LightCyan"
-# Represents the colour the GPU will use in the memory legend and graph.
-#gpu_core_colors=["LightGreen", "LightBlue", "LightRed", "Cyan", "Green", "Blue", "Red"]
-# Represents the colour rx will use in the network legend and graph.
-#rx_color="LightCyan"
-# Represents the colour tx will use in the network legend and graph.
-#tx_color="LightGreen"
-# Represents the colour of the border of unselected widgets.
-#border_color="Gray"
-# Represents the colour of the border of selected widgets.
-#highlighted_border_color="LightBlue"
-# Represents the colour of most text.
-#text_color="Gray"
-# Represents the colour of text that is selected.
-#selected_text_color="Black"
-# Represents the background colour of text that is selected.
-#selected_bg_color="LightBlue"
-# Represents the colour of the lines and text of the graph.
-#graph_color="Gray"
-# Represents the colours of the battery based on charge
-#high_battery_color="green"
-#medium_battery_color="yellow"
-#low_battery_color="red"
+# Built-in themes. Valid values are:
+# - "default"
+# - "default-light"
+# - "gruvbox"
+# - "gruvbox-light"
+# - "nord"
+# - "nord-light".
+#
+# This will have the lowest precedence if a custom colour palette is set,
+# or overridden if the command-line flag for a built-in theme is set.
+#theme = "default"
+
+#[styles.cpu]
+#all_entry_color = "green"
+#avg_entry_color = "red"
+#cpu_core_colors = ["light magenta", "light yellow", "light cyan", "light green", "light blue", "cyan", "green", "blue"]
+
+#[styles.memory]
+#ram_color = "light magenta"
+#cache_color = "light red"
+#swap_color = "light yellow"
+#arc_color = "light cyan"
+#gpu_colors = ["light blue", "light red", "cyan", "green", "blue", "red"]
+
+#[styles.network]
+#rx_color = "light magenta"
+#tx_color = "light yellow"
+#rx_total_color = "light cyan"
+#tx_total_color = "light green"
+
+#[styles.battery]
+#high_battery_color = "green"
+#medium_battery_color = "yellow"
+#low_battery_color = "red"
+
+#[styles.tables]
+#headers = {color = "light blue", bold = true}
+
+#[styles.graphs]
+#graph_color = "gray"
+#legend_text = {color = "gray"}
+
+#[styles.widgets]
+#border_color = "gray"
+#selected_border_color = "light blue"
+#widget_title = {color = "gray"}
+#text = {color = "gray"}
+#selected_text = {color = "black", bg_color = "light blue"}
+#disabled_text = {color = "dark gray"}
 
 # Layout - layouts follow a pattern like this:
 # [[row]] represents a row in the application.
@@ -664,38 +473,7 @@ pub const CONFIG_TEXT: &str = r##"# This is a default config file for bottom.  A
 #  [[row.child]]
 #    type="proc"
 #    default=true
-
-
-# Filters - you can hide specific temperature sensors, network interfaces, and disks using filters.  This is admittedly
-# a bit hard to use as of now, and there is a planned in-app interface for managing this in the future:
-#[disk_filter]
-#is_list_ignored = true
-#list = ["/dev/sda\\d+", "/dev/nvme0n1p2"]
-#regex = true
-#case_sensitive = false
-#whole_word = false
-
-#[mount_filter]
-#is_list_ignored = true
-#list = ["/mnt/.*", "/boot"]
-#regex = true
-#case_sensitive = false
-#whole_word = false
-
-#[temp_filter]
-#is_list_ignored = true
-#list = ["cpu", "wifi"]
-#regex = false
-#case_sensitive = false
-#whole_word = false
-
-#[net_filter]
-#is_list_ignored = true
-#list = ["virbr0.*"]
-#regex = true
-#case_sensitive = false
-#whole_word = false
-"##;
+"#;
 
 pub const CONFIG_TOP_HEAD: &str = r##"# This is bottom's config file.
 # Values in this config file will change when changed in the interface.
@@ -706,19 +484,19 @@ pub const CONFIG_TOP_HEAD: &str = r##"# This is bottom's config file.
 
 "##;
 
-pub const CONFIG_DISPLAY_OPTIONS_HEAD: &str = r##"
+pub const CONFIG_DISPLAY_OPTIONS_HEAD: &str = r#"
 # These options represent settings that affect how bottom functions.
-# If a setting here corresponds to command-line flag, then the flag will temporarily override
+# If a setting here corresponds to command-line option, then the flag will temporarily override
 # the setting.
-"##;
+"#;
 
-pub const CONFIG_COLOUR_HEAD: &str = r##"
+pub const CONFIG_COLOUR_HEAD: &str = r#"
 # These options represent colour values for various parts of bottom.  Note that colour support
 # will ultimately depend on the terminal - for example, the Terminal for macOS does NOT like
 # custom colours and it may glitch out.
-"##;
+"#;
 
-pub const CONFIG_LAYOUT_HEAD: &str = r##"
+pub const CONFIG_LAYOUT_HEAD: &str = r#"
 # These options represent how bottom will lay out its widgets.  Layouts follow a pattern like this:
 # [[row]] represents a row in the application.
 # [[row.child]] represents either a widget or a column.
@@ -726,11 +504,11 @@ pub const CONFIG_LAYOUT_HEAD: &str = r##"
 #
 # All widgets must have the valid type value set to one of ["cpu", "mem", "proc", "net", "temp", "disk", "empty"].
 # All layout components have a ratio value - if this is not set, then it defaults to 1.
-"##;
+"#;
 
-pub const CONFIG_FILTER_HEAD: &str = r##"
+pub const CONFIG_FILTER_HEAD: &str = r#"
 # These options represent disabled entries for the temperature and disk widgets.
-"##;
+"#;
 
 #[cfg(test)]
 mod test {
@@ -738,6 +516,7 @@ mod test {
 
     #[test]
     fn help_menu_matches_entry_len() {
+        // The two match since HELP_TEXT contains HELP_CONTENTS_TEXT as an entry
         assert_eq!(
             HELP_CONTENTS_TEXT.len(),
             HELP_TEXT.len(),
@@ -745,8 +524,18 @@ mod test {
         )
     }
 
-    /// This test exists because previously, [`SIDE_BORDERS`] was set incorrectly after I moved from
-    /// tui-rs to ratatui.
+    #[test]
+    fn help_menu_text_has_sections() {
+        for (itx, line) in HELP_TEXT.iter().enumerate() {
+            if itx > 0 {
+                assert!(line.len() >= 2, "each section should be at least 2 lines");
+                assert!(line[0].contains(" - "), "each section should have a header");
+            }
+        }
+    }
+
+    /// This test exists because previously, [`SIDE_BORDERS`] was set
+    /// incorrectly after I moved from tui-rs to ratatui.
     #[test]
     fn assert_side_border_bits_match() {
         assert_eq!(
