@@ -1,17 +1,20 @@
-use std::{borrow::Cow, time::Instant};
+use std::{borrow::Cow, num::NonZeroU16, time::Instant};
 
 use concat_string::concat_string;
-use tui::{style::Style, text::Text, widgets::Row};
+use tui::{style::Style, widgets::Row};
 
 use crate::{
-    app::{data_harvester::cpu::CpuDataType, AppConfigFields},
-    canvas::{canvas_styling::CanvasStyling, Painter},
-    components::data_table::{
-        Column, ColumnHeader, DataTable, DataTableColumn, DataTableProps, DataTableStyling,
-        DataToCell,
+    app::AppConfigFields,
+    canvas::{
+        components::data_table::{
+            Column, ColumnHeader, DataTable, DataTableColumn, DataTableProps, DataTableStyling,
+            DataToCell,
+        },
+        Painter,
     },
+    data_collection::cpu::CpuDataType,
     data_conversion::CpuWidgetData,
-    utils::gen_util::truncate_to_text,
+    options::config::{cpu::CpuDefault, style::ColourPalette},
 };
 
 #[derive(Default)]
@@ -22,16 +25,16 @@ pub struct CpuWidgetStyling {
 }
 
 impl CpuWidgetStyling {
-    fn from_colours(colours: &CanvasStyling) -> Self {
-        let entries = if colours.cpu_colour_styles.is_empty() {
+    fn from_colours(palette: &ColourPalette) -> Self {
+        let entries = if palette.cpu_colour_styles.is_empty() {
             vec![Style::default()]
         } else {
-            colours.cpu_colour_styles.clone()
+            palette.cpu_colour_styles.clone()
         };
 
         Self {
-            all: colours.all_colour_style,
-            avg: colours.avg_colour_style,
+            all: palette.all_cpu_colour,
+            avg: palette.avg_cpu_colour,
             entries,
         }
     }
@@ -46,7 +49,7 @@ impl ColumnHeader for CpuWidgetColumn {
     fn text(&self) -> Cow<'static, str> {
         match self {
             CpuWidgetColumn::CPU => "CPU".into(),
-            CpuWidgetColumn::Use => "Use%".into(),
+            CpuWidgetColumn::Use => "Use".into(),
         }
     }
 }
@@ -76,16 +79,20 @@ impl CpuWidgetTableData {
 }
 
 impl DataToCell<CpuWidgetColumn> for CpuWidgetTableData {
-    fn to_cell<'a>(&'a self, column: &CpuWidgetColumn, calculated_width: u16) -> Option<Text<'a>> {
+    fn to_cell(
+        &self, column: &CpuWidgetColumn, calculated_width: NonZeroU16,
+    ) -> Option<Cow<'static, str>> {
         const CPU_TRUNCATE_BREAKPOINT: u16 = 5;
 
-        // This is a bit of a hack, but apparently we can avoid having to do any fancy checks
-        // of showing the "All" on a specific column if the other is hidden by just always
-        // showing it on the CPU (first) column - if there isn't room for it, it will just collapse
-        // down.
+        let calculated_width = calculated_width.get();
+
+        // This is a bit of a hack, but apparently we can avoid having to do any fancy
+        // checks of showing the "All" on a specific column if the other is
+        // hidden by just always showing it on the CPU (first) column - if there
+        // isn't room for it, it will just collapse down.
         //
-        // This is the same for the use percentages - we just *always* show them, and *always* hide the CPU column if
-        // it is too small.
+        // This is the same for the use percentages - we just *always* show them, and
+        // *always* hide the CPU column if it is too small.
         match &self {
             CpuWidgetTableData::All => match column {
                 CpuWidgetColumn::CPU => Some("All".into()),
@@ -100,25 +107,19 @@ impl DataToCell<CpuWidgetColumn> for CpuWidgetTableData {
                 } else {
                     match column {
                         CpuWidgetColumn::CPU => match data_type {
-                            CpuDataType::Avg => Some(truncate_to_text("AVG", calculated_width)),
+                            CpuDataType::Avg => Some("AVG".into()),
                             CpuDataType::Cpu(index) => {
                                 let index_str = index.to_string();
                                 let text = if calculated_width < CPU_TRUNCATE_BREAKPOINT {
-                                    truncate_to_text(&index_str, calculated_width)
+                                    index_str.into()
                                 } else {
-                                    truncate_to_text(
-                                        &concat_string!("CPU", index_str),
-                                        calculated_width,
-                                    )
+                                    concat_string!("CPU", index_str).into()
                                 };
 
                                 Some(text)
                             }
                         },
-                        CpuWidgetColumn::Use => Some(truncate_to_text(
-                            &format!("{:.0}%", last_entry.round()),
-                            calculated_width,
-                        )),
+                        CpuWidgetColumn::Use => Some(format!("{:.0}%", last_entry.round()).into()),
                     }
                 }
             }
@@ -128,12 +129,12 @@ impl DataToCell<CpuWidgetColumn> for CpuWidgetTableData {
     #[inline(always)]
     fn style_row<'a>(&self, row: Row<'a>, painter: &Painter) -> Row<'a> {
         let style = match self {
-            CpuWidgetTableData::All => painter.colours.all_colour_style,
+            CpuWidgetTableData::All => painter.colours.all_cpu_colour,
             CpuWidgetTableData::Entry {
                 data_type,
                 last_entry: _,
             } => match data_type {
-                CpuDataType::Avg => painter.colours.avg_colour_style,
+                CpuDataType::Avg => painter.colours.avg_cpu_colour,
                 CpuDataType::Cpu(index) => {
                     painter.colours.cpu_colour_styles
                         [index % painter.colours.cpu_colour_styles.len()]
@@ -165,8 +166,8 @@ pub struct CpuWidgetState {
 
 impl CpuWidgetState {
     pub fn new(
-        config: &AppConfigFields, current_display_time: u64, autohide_timer: Option<Instant>,
-        colours: &CanvasStyling,
+        config: &AppConfigFields, default_selection: CpuDefault, current_display_time: u64,
+        autohide_timer: Option<Instant>, colours: &ColourPalette,
     ) -> Self {
         const COLUMNS: [Column<CpuWidgetColumn>; 2] = [
             Column::soft(CpuWidgetColumn::CPU, Some(0.5)),
@@ -182,14 +183,22 @@ impl CpuWidgetState {
             show_current_entry_when_unfocused: true,
         };
 
-        let styling = DataTableStyling::from_colours(colours);
+        let styling = DataTableStyling::from_palette(colours);
+        let mut table = DataTable::new(COLUMNS, props, styling);
+        match default_selection {
+            CpuDefault::All => {}
+            CpuDefault::Average if !config.show_average_cpu => {}
+            CpuDefault::Average => {
+                table = table.first_draw_index(1);
+            }
+        }
 
         CpuWidgetState {
             current_display_time,
             is_legend_hidden: false,
             show_avg: config.show_average_cpu,
             autohide_timer,
-            table: DataTable::new(COLUMNS, props, styling),
+            table,
             styling: CpuWidgetStyling::from_colours(colours),
         }
     }
