@@ -1,32 +1,29 @@
-use std::{borrow::Cow, cmp::max};
-
-use kstring::KString;
-use tui::text::Text;
+use std::{borrow::Cow, cmp::max, num::NonZeroU16};
 
 use crate::{
     app::AppConfigFields,
-    canvas::canvas_styling::CanvasColours,
-    components::data_table::{
+    canvas::components::data_table::{
         ColumnHeader, DataTableColumn, DataTableProps, DataTableStyling, DataToCell, SortColumn,
         SortDataTable, SortDataTableProps, SortOrder, SortsRow,
     },
-    utils::gen_util::{get_decimal_bytes, sort_partial_fn, truncate_to_text},
+    options::config::style::ColourPalette,
+    utils::{data_prefixes::get_decimal_bytes, general::sort_partial_fn},
 };
 
 #[derive(Clone, Debug)]
 pub struct DiskWidgetData {
-    pub name: KString,
-    pub mount_point: KString,
+    pub name: Cow<'static, str>,
+    pub mount_point: Cow<'static, str>,
     pub free_bytes: Option<u64>,
     pub used_bytes: Option<u64>,
     pub total_bytes: Option<u64>,
     pub summed_total_bytes: Option<u64>,
-    pub io_read: KString,
-    pub io_write: KString,
+    pub io_read: Cow<'static, str>,
+    pub io_write: Cow<'static, str>,
 }
 
 impl DiskWidgetData {
-    pub fn total_space(&self) -> KString {
+    fn total_space(&self) -> Cow<'static, str> {
         if let Some(total_bytes) = self.total_bytes {
             let converted_total_space = get_decimal_bytes(total_bytes);
             format!(
@@ -39,7 +36,7 @@ impl DiskWidgetData {
         }
     }
 
-    pub fn free_space(&self) -> KString {
+    fn free_space(&self) -> Cow<'static, str> {
         if let Some(free_bytes) = self.free_bytes {
             let converted_free_space = get_decimal_bytes(free_bytes);
             format!("{:.*}{}", 0, converted_free_space.0, converted_free_space.1).into()
@@ -48,7 +45,7 @@ impl DiskWidgetData {
         }
     }
 
-    pub fn used_space(&self) -> KString {
+    fn used_space(&self) -> Cow<'static, str> {
         if let Some(used_bytes) = self.used_bytes {
             let converted_free_space = get_decimal_bytes(used_bytes);
             format!("{:.*}{}", 0, converted_free_space.0, converted_free_space.1).into()
@@ -57,7 +54,7 @@ impl DiskWidgetData {
         }
     }
 
-    pub fn free_percent(&self) -> Option<f64> {
+    fn free_percent(&self) -> Option<f64> {
         if let (Some(free_bytes), Some(summed_total_bytes)) =
             (self.free_bytes, self.summed_total_bytes)
         {
@@ -67,14 +64,14 @@ impl DiskWidgetData {
         }
     }
 
-    pub fn free_percent_string(&self) -> KString {
+    fn free_percent_string(&self) -> Cow<'static, str> {
         match self.free_percent() {
-            Some(val) => format!("{:.1}%", val).into(),
+            Some(val) => format!("{val:.1}%").into(),
             None => "N/A".into(),
         }
     }
 
-    pub fn used_percent(&self) -> Option<f64> {
+    fn used_percent(&self) -> Option<f64> {
         if let (Some(used_bytes), Some(summed_total_bytes)) =
             (self.used_bytes, self.summed_total_bytes)
         {
@@ -88,9 +85,9 @@ impl DiskWidgetData {
         }
     }
 
-    pub fn used_percent_string(&self) -> KString {
+    fn used_percent_string(&self) -> Cow<'static, str> {
         match self.used_percent() {
-            Some(val) => format!("{:.1}%", val).into(),
+            Some(val) => format!("{val:.1}%").into(),
             None => "N/A".into(),
         }
     }
@@ -126,25 +123,19 @@ impl ColumnHeader for DiskWidgetColumn {
 }
 
 impl DataToCell<DiskWidgetColumn> for DiskWidgetData {
-    fn to_cell<'a>(&'a self, column: &DiskWidgetColumn, calculated_width: u16) -> Option<Text<'a>> {
-        if calculated_width == 0 {
-            return None;
-        }
-
+    fn to_cell(
+        &self, column: &DiskWidgetColumn, _calculated_width: NonZeroU16,
+    ) -> Option<Cow<'static, str>> {
         let text = match column {
-            DiskWidgetColumn::Disk => truncate_to_text(&self.name, calculated_width),
-            DiskWidgetColumn::Mount => truncate_to_text(&self.mount_point, calculated_width),
-            DiskWidgetColumn::Used => truncate_to_text(&self.used_space(), calculated_width),
-            DiskWidgetColumn::Free => truncate_to_text(&self.free_space(), calculated_width),
-            DiskWidgetColumn::UsedPercent => {
-                truncate_to_text(&self.used_percent_string(), calculated_width)
-            }
-            DiskWidgetColumn::FreePercent => {
-                truncate_to_text(&self.free_percent_string(), calculated_width)
-            }
-            DiskWidgetColumn::Total => truncate_to_text(&self.total_space(), calculated_width),
-            DiskWidgetColumn::IoRead => truncate_to_text(&self.io_read, calculated_width),
-            DiskWidgetColumn::IoWrite => truncate_to_text(&self.io_write, calculated_width),
+            DiskWidgetColumn::Disk => self.name.clone(),
+            DiskWidgetColumn::Mount => self.mount_point.clone(),
+            DiskWidgetColumn::Used => self.used_space(),
+            DiskWidgetColumn::Free => self.free_space(),
+            DiskWidgetColumn::UsedPercent => self.used_percent_string(),
+            DiskWidgetColumn::FreePercent => self.free_percent_string(),
+            DiskWidgetColumn::Total => self.total_space(),
+            DiskWidgetColumn::IoRead => self.io_read.clone(),
+            DiskWidgetColumn::IoWrite => self.io_write.clone(),
         };
 
         Some(text)
@@ -213,7 +204,7 @@ impl SortsRow for DiskWidgetColumn {
 }
 
 impl DiskTableWidget {
-    pub fn new(config: &AppConfigFields, colours: &CanvasColours) -> Self {
+    pub fn new(config: &AppConfigFields, palette: &ColourPalette) -> Self {
         let columns = [
             SortColumn::soft(DiskWidgetColumn::Disk, Some(0.2)),
             SortColumn::soft(DiskWidgetColumn::Mount, Some(0.2)),
@@ -238,7 +229,7 @@ impl DiskTableWidget {
             order: SortOrder::Ascending,
         };
 
-        let styling = DataTableStyling::from_colours(colours);
+        let styling = DataTableStyling::from_palette(palette);
 
         Self {
             table: SortDataTable::new_sortable(columns, props, styling),
@@ -252,7 +243,8 @@ impl DiskTableWidget {
         self.force_update_data = true;
     }
 
-    pub fn ingest_data(&mut self, data: &[DiskWidgetData]) {
+    /// Update the current table data.
+    pub fn set_table_data(&mut self, data: &[DiskWidgetData]) {
         let mut data = data.to_vec();
         if let Some(column) = self.table.columns.get(self.table.sort_index()) {
             column.sort_by(&mut data, self.table.order());
