@@ -1,35 +1,32 @@
+pub mod proc_widget_column;
+pub mod proc_widget_data;
+mod sort_table;
+
 use std::{borrow::Cow, collections::BTreeMap};
 
 use hashbrown::{HashMap, HashSet};
 use indexmap::IndexSet;
 use itertools::Itertools;
-use serde::{de::Error, Deserialize};
+pub use proc_widget_column::*;
+pub use proc_widget_data::*;
+use sort_table::SortTableColumn;
 
 use crate::{
     app::{
         data_farmer::{DataCollection, ProcessData},
-        data_harvester::processes::ProcessHarvest,
         query::*,
         AppConfigFields, AppSearchState,
     },
-    canvas::canvas_styling::CanvasStyling,
-    components::data_table::{
+    canvas::components::data_table::{
         Column, ColumnHeader, ColumnWidthBounds, DataTable, DataTableColumn, DataTableProps,
         DataTableStyling, SortColumn, SortDataTable, SortDataTableProps, SortOrder, SortsRow,
     },
-    Pid,
+    data_collection::processes::{Pid, ProcessHarvest},
+    options::config::style::ColourPalette,
 };
 
-pub mod proc_widget_column;
-pub use proc_widget_column::*;
-
-pub mod proc_widget_data;
-pub use proc_widget_data::*;
-
-mod sort_table;
-use sort_table::SortTableColumn;
-
-/// ProcessSearchState only deals with process' search's current settings and state.
+/// ProcessSearchState only deals with process' search's current settings and
+/// state.
 pub struct ProcessSearchState {
     pub search_state: AppSearchState,
     pub is_ignoring_case: bool,
@@ -89,8 +86,14 @@ fn make_column(column: ProcColumn) -> SortColumn<ProcColumn> {
         TotalRead => SortColumn::hard(TotalRead, 8).default_descending(),
         TotalWrite => SortColumn::hard(TotalWrite, 8).default_descending(),
         User => SortColumn::soft(User, Some(0.05)),
-        State => SortColumn::hard(State, 7),
+        State => SortColumn::hard(State, 9),
         Time => SortColumn::new(Time),
+        #[cfg(feature = "gpu")]
+        GpuMem => SortColumn::new(GpuMem).default_descending(),
+        #[cfg(feature = "gpu")]
+        GpuMemPercent => SortColumn::new(GpuMemPercent).default_descending(),
+        #[cfg(feature = "gpu")]
+        GpuUtilPercent => SortColumn::new(GpuUtilPercent).default_descending(),
     }
 }
 
@@ -117,32 +120,10 @@ pub enum ProcWidgetColumn {
     User,
     State,
     Time,
-}
-
-impl<'de> Deserialize<'de> for ProcWidgetColumn {
-    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
-    where
-        D: serde::Deserializer<'de>,
-    {
-        let value = String::deserialize(deserializer)?.to_lowercase();
-        match value.as_str() {
-            "cpu%" => Ok(ProcWidgetColumn::Cpu),
-            "mem" => Ok(ProcWidgetColumn::Mem),
-            "mem%" => Ok(ProcWidgetColumn::Mem),
-            "pid" => Ok(ProcWidgetColumn::PidOrCount),
-            "count" => Ok(ProcWidgetColumn::PidOrCount),
-            "name" => Ok(ProcWidgetColumn::ProcNameOrCommand),
-            "command" => Ok(ProcWidgetColumn::ProcNameOrCommand),
-            "read" | "r/s" | "rps" => Ok(ProcWidgetColumn::ReadPerSecond),
-            "write" | "w/s" | "wps" => Ok(ProcWidgetColumn::WritePerSecond),
-            "tread" | "t.read" => Ok(ProcWidgetColumn::TotalRead),
-            "twrite" | "t.write" => Ok(ProcWidgetColumn::TotalWrite),
-            "state" => Ok(ProcWidgetColumn::State),
-            "user" => Ok(ProcWidgetColumn::User),
-            "time" => Ok(ProcWidgetColumn::Time),
-            _ => Err(D::Error::custom("doesn't match any column type")),
-        }
-    }
+    #[cfg(feature = "gpu")]
+    GpuMem,
+    #[cfg(feature = "gpu")]
+    GpuUtil,
 }
 
 // This is temporary. Switch back to `ProcColumn` later!
@@ -159,7 +140,8 @@ pub struct ProcWidgetState {
     /// The state of the togglable table that controls sorting.
     pub sort_table: SortTable,
 
-    /// The internal column mapping as an [`IndexSet`], to allow us to do quick mappings of column type -> index.
+    /// The internal column mapping as an [`IndexSet`], to allow us to do quick
+    /// mappings of column type -> index.
     pub column_mapping: IndexSet<ProcWidgetColumn>,
 
     /// A name-to-pid mapping.
@@ -177,7 +159,7 @@ pub struct ProcWidgetState {
 }
 
 impl ProcWidgetState {
-    fn new_sort_table(config: &AppConfigFields, colours: &CanvasStyling) -> SortTable {
+    fn new_sort_table(config: &AppConfigFields, palette: &ColourPalette) -> SortTable {
         const COLUMNS: [Column<SortTableColumn>; 1] = [Column::hard(SortTableColumn, 7)];
 
         let props = DataTableProps {
@@ -188,13 +170,13 @@ impl ProcWidgetState {
             show_table_scroll_position: false,
             show_current_entry_when_unfocused: false,
         };
-        let styling = DataTableStyling::from_colours(colours);
+        let styling = DataTableStyling::from_palette(palette);
 
         DataTable::new(COLUMNS, props, styling)
     }
 
     fn new_process_table(
-        config: &AppConfigFields, colours: &CanvasStyling, columns: Vec<SortColumn<ProcColumn>>,
+        config: &AppConfigFields, colours: &ColourPalette, columns: Vec<SortColumn<ProcColumn>>,
         default_index: usize, default_order: SortOrder,
     ) -> ProcessTable {
         let inner_props = DataTableProps {
@@ -210,14 +192,14 @@ impl ProcWidgetState {
             sort_index: default_index,
             order: default_order,
         };
-        let styling = DataTableStyling::from_colours(colours);
+        let styling = DataTableStyling::from_palette(colours);
 
         DataTable::new_sortable(columns, props, styling)
     }
 
     pub fn new(
         config: &AppConfigFields, mode: ProcWidgetMode, table_config: ProcTableConfig,
-        colours: &CanvasStyling, config_columns: &Option<IndexSet<ProcWidgetColumn>>,
+        colours: &ColourPalette, config_columns: &Option<IndexSet<ProcWidgetColumn>>,
     ) -> Self {
         let process_search_state = {
             let mut pss = ProcessSearchState::default();
@@ -241,7 +223,7 @@ impl ProcWidgetState {
 
             let is_count = matches!(mode, ProcWidgetMode::Grouped);
             let is_command = table_config.is_command;
-            let mem_vals = table_config.show_memory_as_values;
+            let mem_as_values = table_config.show_memory_as_values;
 
             match config_columns {
                 Some(columns) if !columns.is_empty() => columns
@@ -264,7 +246,7 @@ impl ProcWidgetState {
                             }
                             ProcWidgetColumn::Cpu => CpuPercent,
                             ProcWidgetColumn::Mem => {
-                                if mem_vals {
+                                if mem_as_values {
                                     MemoryVal
                                 } else {
                                     MemoryPercent
@@ -277,6 +259,16 @@ impl ProcWidgetState {
                             ProcWidgetColumn::User => User,
                             ProcWidgetColumn::State => State,
                             ProcWidgetColumn::Time => Time,
+                            #[cfg(feature = "gpu")]
+                            ProcWidgetColumn::GpuMem => {
+                                if mem_as_values {
+                                    GpuMem
+                                } else {
+                                    GpuMemPercent
+                                }
+                            }
+                            #[cfg(feature = "gpu")]
+                            ProcWidgetColumn::GpuUtil => GpuUtilPercent,
                         };
 
                         make_column(col)
@@ -287,13 +279,18 @@ impl ProcWidgetState {
                         if is_count { Count } else { Pid },
                         if is_command { Command } else { Name },
                         CpuPercent,
-                        if mem_vals { MemoryVal } else { MemoryPercent },
+                        if mem_as_values {
+                            MemoryVal
+                        } else {
+                            MemoryPercent
+                        },
                         ReadPerSecond,
                         WritePerSecond,
                         TotalRead,
                         TotalWrite,
                         User,
                         State,
+                        Time,
                     ];
 
                     default_columns.into_iter().map(make_column).collect()
@@ -318,6 +315,10 @@ impl ProcWidgetState {
                     State => ProcWidgetColumn::State,
                     User => ProcWidgetColumn::User,
                     Time => ProcWidgetColumn::Time,
+                    #[cfg(feature = "gpu")]
+                    GpuMem | GpuMemPercent => ProcWidgetColumn::GpuMem,
+                    #[cfg(feature = "gpu")]
+                    GpuUtilPercent => ProcWidgetColumn::GpuUtil,
                 }
             })
             .collect::<IndexSet<_>>();
@@ -392,9 +393,12 @@ impl ProcWidgetState {
         }
     }
 
-    /// This function *only* updates the displayed process data. If there is a need to update the actual *stored* data,
-    /// call it before this function.
-    pub fn ingest_data(&mut self, data_collection: &DataCollection) {
+    /// Update the current table data.
+    ///
+    /// This function *only* updates the displayed process data. If there is a
+    /// need to update the actual *stored* data, call it before this
+    /// function.
+    pub fn set_table_data(&mut self, data_collection: &DataCollection) {
         let data = match &self.mode {
             ProcWidgetMode::Grouped | ProcWidgetMode::Normal => {
                 self.get_normal_data(&data_collection.process_data.process_harvest)
@@ -461,7 +465,8 @@ impl ProcWidgetState {
             }
         }
 
-        // A process is shown under the filtered tree if at least one of these conditions hold:
+        // A process is shown under the filtered tree if at least one of these
+        // conditions hold:
         // - The process itself matches.
         // - The process contains some descendant that matches.
         // - The process's parent (and only parent, not any ancestor) matches.
@@ -490,7 +495,8 @@ impl ProcWidgetState {
 
                         // Show the entry if it is:
                         // - Matches the filter.
-                        // - Has at least one child (doesn't have to be direct) that matches the filter.
+                        // - Has at least one child (doesn't have to be direct) that matches the
+                        //   filter.
                         // - Is the child of a shown process.
                         let is_shown = is_process_matching
                             || !shown_children.is_empty()
@@ -690,7 +696,8 @@ impl ProcWidgetState {
                 if let Some(grouped_process_harvest) = id_process_mapping.get_mut(id) {
                     grouped_process_harvest.add(process);
                 } else {
-                    // FIXME: [PERF] could maybe eliminate an allocation here in the grouped mode... or maybe just avoid the entire transformation step, making an alloc fine.
+                    // FIXME: [PERF] could maybe eliminate an allocation here in the grouped mode...
+                    // or maybe just avoid the entire transformation step, making an alloc fine.
                     id_process_mapping.insert(id, process.clone());
                 }
             }
@@ -743,6 +750,23 @@ impl ProcWidgetState {
                     _ => unreachable!(),
                 }
 
+                self.sort_table.set_data(self.column_text());
+                self.force_data_update();
+            }
+        }
+        #[cfg(feature = "gpu")]
+        if let Some(index) = self.column_mapping.get_index_of(&ProcWidgetColumn::GpuMem) {
+            if let Some(mem) = self.get_mut_proc_col(index) {
+                match mem {
+                    ProcColumn::GpuMem => {
+                        *mem = ProcColumn::GpuMemPercent;
+                    }
+                    ProcColumn::GpuMemPercent => {
+                        *mem = ProcColumn::GpuMem;
+                    }
+                    _ => unreachable!(),
+                }
+
                 self.sort_table.set_data(self.column_text());
                 self.force_data_update();
             }
@@ -762,8 +786,8 @@ impl ProcWidgetState {
         self.force_update_data = true;
     }
 
-    /// Marks the selected column as hidden, and automatically resets the selected column to the default
-    /// sort index and order.
+    /// Marks the selected column as hidden, and automatically resets the
+    /// selected column to the default sort index and order.
     fn hide_column(&mut self, column: ProcWidgetColumn) {
         if let Some(index) = self.column_mapping.get_index_of(&column) {
             if let Some(col) = self.table.columns.get_mut(index) {
@@ -786,7 +810,8 @@ impl ProcWidgetState {
         }
     }
 
-    /// Select a column. If the column is already selected, then just toggle the sort order.
+    /// Select a column. If the column is already selected, then just toggle the
+    /// sort order.
     pub fn select_column(&mut self, column: ProcWidgetColumn) {
         if let Some(index) = self.column_mapping.get_index_of(&column) {
             self.table.set_sort_index(index);
@@ -840,12 +865,15 @@ impl ProcWidgetState {
 
     /// Toggles the appropriate columns/settings when tab is pressed.
     ///
-    /// If count is enabled, we should set the mode to [`ProcWidgetMode::Grouped`], and switch off the User and State
-    /// columns. We should also move the user off of the columns if they were selected, as those columns are now hidden
-    /// (handled by internal method calls), and go back to the "defaults".
+    /// If count is enabled, we should set the mode to
+    /// [`ProcWidgetMode::Grouped`], and switch off the User and State
+    /// columns. We should also move the user off of the columns if they were
+    /// selected, as those columns are now hidden (handled by internal
+    /// method calls), and go back to the "defaults".
     ///
-    /// Otherwise, if count is disabled, then if the columns exist, the User and State columns should be re-enabled,
-    /// and the mode switched to [`ProcWidgetMode::Normal`].
+    /// Otherwise, if count is disabled, then if the columns exist, the User and
+    /// State columns should be re-enabled, and the mode switched to
+    /// [`ProcWidgetMode::Normal`].
     pub fn toggle_tab(&mut self) {
         if !matches!(self.mode, ProcWidgetMode::Tree { .. }) {
             if let Some(index) = self
@@ -954,14 +982,15 @@ impl ProcWidgetState {
         self.proc_search.search_state.walk_backward();
     }
 
-    /// Returns the number of columns *enabled*. Note this differs from *visible* - a column may be enabled but not
-    /// visible (e.g. off screen).
+    /// Returns the number of columns *enabled*. Note this differs from
+    /// *visible* - a column may be enabled but not visible (e.g. off
+    /// screen).
     pub fn num_enabled_columns(&self) -> usize {
         self.table.columns.iter().filter(|c| !c.is_hidden).count()
     }
 
-    /// Sets the [`ProcWidget`]'s current sort index to whatever was in the sort table if possible, then closes the
-    /// sort table.
+    /// Sets the [`ProcWidgetState`]'s current sort index to whatever was in the
+    /// sort table if possible, then closes the sort table.
     pub(crate) fn use_sort_table_value(&mut self) {
         self.table.set_sort_index(self.sort_table.current_index());
 
@@ -1029,6 +1058,10 @@ mod test {
             num_similar: 0,
             disabled: false,
             time: Duration::from_secs(0),
+            #[cfg(feature = "gpu")]
+            gpu_mem_usage: MemUsage::Percent(1.1),
+            #[cfg(feature = "gpu")]
+            gpu_usage: 0,
         };
 
         let b = ProcWidgetData {
@@ -1063,10 +1096,7 @@ mod test {
         data.sort_by_key(|p| p.pid);
         sort_skip_pid_asc(&ProcColumn::CpuPercent, &mut data, SortOrder::Descending);
         assert_eq!(
-            vec![&c, &b, &a, &d]
-                .iter()
-                .map(|d| (d.pid))
-                .collect::<Vec<_>>(),
+            [&c, &b, &a, &d].iter().map(|d| (d.pid)).collect::<Vec<_>>(),
             data.iter().map(|d| (d.pid)).collect::<Vec<_>>(),
         );
 
@@ -1074,20 +1104,14 @@ mod test {
         data.sort_by_key(|p| p.pid);
         sort_skip_pid_asc(&ProcColumn::CpuPercent, &mut data, SortOrder::Ascending);
         assert_eq!(
-            vec![&a, &d, &b, &c]
-                .iter()
-                .map(|d| (d.pid))
-                .collect::<Vec<_>>(),
+            [&a, &d, &b, &c].iter().map(|d| (d.pid)).collect::<Vec<_>>(),
             data.iter().map(|d| (d.pid)).collect::<Vec<_>>(),
         );
 
         data.sort_by_key(|p| p.pid);
         sort_skip_pid_asc(&ProcColumn::MemoryPercent, &mut data, SortOrder::Descending);
         assert_eq!(
-            vec![&b, &a, &c, &d]
-                .iter()
-                .map(|d| (d.pid))
-                .collect::<Vec<_>>(),
+            [&b, &a, &c, &d].iter().map(|d| (d.pid)).collect::<Vec<_>>(),
             data.iter().map(|d| (d.pid)).collect::<Vec<_>>(),
         );
 
@@ -1095,10 +1119,7 @@ mod test {
         data.sort_by_key(|p| p.pid);
         sort_skip_pid_asc(&ProcColumn::MemoryPercent, &mut data, SortOrder::Ascending);
         assert_eq!(
-            vec![&c, &d, &a, &b]
-                .iter()
-                .map(|d| (d.pid))
-                .collect::<Vec<_>>(),
+            [&c, &d, &a, &b].iter().map(|d| (d.pid)).collect::<Vec<_>>(),
             data.iter().map(|d| (d.pid)).collect::<Vec<_>>(),
         );
     }
@@ -1119,7 +1140,7 @@ mod test {
 
     fn init_state(table_config: ProcTableConfig, columns: &[ProcWidgetColumn]) -> ProcWidgetState {
         let config = AppConfigFields::default();
-        let styling = CanvasStyling::default();
+        let styling = ColourPalette::default();
         let columns = Some(columns.iter().cloned().collect());
 
         ProcWidgetState::new(
@@ -1382,8 +1403,9 @@ mod test {
 
     /// Tests toggling if both mem and mem% columns are configured.
     ///
-    /// Currently, this test doesn't really do much, since we treat these two columns as the same - this test is
-    /// intended for use later when we might allow both at the same time.
+    /// Currently, this test doesn't really do much, since we treat these two
+    /// columns as the same - this test is intended for use later when we
+    /// might allow both at the same time.
     #[test]
     fn double_memory_sim_toggle() {
         let init_columns = [
@@ -1418,8 +1440,9 @@ mod test {
 
     /// Tests toggling if both pid and count columns are configured.
     ///
-    /// Currently, this test doesn't really do much, since we treat these two columns as the same - this test is
-    /// intended for use later when we might allow both at the same time.
+    /// Currently, this test doesn't really do much, since we treat these two
+    /// columns as the same - this test is intended for use later when we
+    /// might allow both at the same time.
     #[test]
     fn pid_and_count_sim_toggle() {
         let init_columns = [
@@ -1455,8 +1478,9 @@ mod test {
 
     /// Tests toggling if both command and name columns are configured.
     ///
-    /// Currently, this test doesn't really do much, since we treat these two columns as the same - this test is
-    /// intended for use later when we might allow both at the same time.
+    /// Currently, this test doesn't really do much, since we treat these two
+    /// columns as the same - this test is intended for use later when we
+    /// might allow both at the same time.
     #[test]
     fn command_name_sim_toggle() {
         let init_columns = [
